@@ -53,6 +53,31 @@ static void Gperror(const char *str)
 }
 
 
+#ifdef NEED_GETHOSTNAME
+#include <sys/utsname.h>
+
+int gethostname(char *buf, int buflen)
+{
+    struct utsname nb;
+
+    
+    if (uname(&nb) < 0)
+	return -1;
+
+    if (strlen(nb.nodename) > buflen-1)
+    {
+	strncpy(buf, nb.nodename, buflen);
+	buf[buflen-1] = '\0';
+    }
+    else
+	strcpy(buf, nb.nodename);
+    
+    return 0;
+}
+
+#endif
+
+
 /*
 ** Return 1 if request comes from an authorized host
 **
@@ -395,8 +420,12 @@ ypresp_val *ypproc_match_2_svc(ypreq_key *key,
 	if (strcmp(key->map, "hosts.byname") == 0)
 	    he = gethostbyname(key->key.keydat_val);
 	else  if (strcmp(key->map, "hosts.byaddr") == 0)
-	    he = gethostbyaddr(inet_addr(key->key.keydat_val), sizeof(long),
-			       AF_INET);
+	{
+	    long a;
+
+	    a = inet_addr(key->key.keydat_val);
+	    he = gethostbyaddr((const char *) &a, sizeof(long), AF_INET);
+	}
 	else
 	    he = NULL;
 	    
@@ -409,7 +438,7 @@ ypresp_val *ypproc_match_2_svc(ypreq_key *key,
 	    if (debug_flag)
 		fprintf(stderr, "\t-> OK (%s/%s)\n",
 			he->h_name,
-			inet_ntoa(he->h_addr));
+			inet_ntoa(* (struct in_addr *) &he->h_addr));
 
 	    len = 16; /* Numerical IP address */
 	    len += strlen(he->h_name) + 1;
@@ -418,7 +447,7 @@ ypresp_val *ypproc_match_2_svc(ypreq_key *key,
 	    
 
 	    cp = malloc(len+1);
-	    strcpy(cp, inet_ntoa(he->h_addr));
+	    strcpy(cp, inet_ntoa(* (struct in_addr *) &he->h_addr));
 	    strcat(cp, " ");
 	    strcat(cp, he->h_name);
 
@@ -446,7 +475,7 @@ ypresp_val *ypproc_match_2_svc(ypreq_key *key,
 
 
 
-ypresp_key_val *ypproc_first_2_svc(ypreq_key *key,
+ypresp_key_val *ypproc_first_2_svc(ypreq_nokey *key,
 				   struct svc_req *rqstp)
 {
     static ypresp_key_val result;
@@ -465,9 +494,11 @@ ypresp_key_val *ypproc_first_2_svc(ypreq_key *key,
 		
 	fprintf(stderr, "\tdomainname = \"%s\"\n", key->domain);
 	fprintf(stderr, "\tmapname = \"%s\"\n", key->map);
+#if 0
 	fprintf(stderr, "\tkeydat = \"%.*s\"\n",
 		(int) key->key.keydat_len,
 		key->key.keydat_val);
+#endif
     }
 
     result.key.keydat_len = 0;
