@@ -15,6 +15,16 @@ extern int perror(const char *str);
 #endif
 
 
+#if (defined(__sun__) || defined(sun)) && defined(__svr4__)
+
+extern char *strdup(const char *str);
+
+#define NEED_GETHOSTNAME
+#define NEED_SVCSOC_H
+
+#endif
+
+
 #if defined(hpux) || defined(__hpux__)
 
 /* HP is really... Ah well. */
